Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3436)

Unified Diff: chrome/browser/tab_contents/render_view_host_manager.cc

Issue 6201005: Initial support for partitioning cookies for isolated apps. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Update cookie logic in test. Created 9 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/tab_contents/render_view_host_manager.cc
diff --git a/chrome/browser/tab_contents/render_view_host_manager.cc b/chrome/browser/tab_contents/render_view_host_manager.cc
index ed5628e9731376f45603da6908967fd43c812b53..4616d9571c07514f2ac26d9a709a4a8691943244 100644
--- a/chrome/browser/tab_contents/render_view_host_manager.cc
+++ b/chrome/browser/tab_contents/render_view_host_manager.cc
@@ -484,11 +484,16 @@ bool RenderViewHostManager::InitRenderView(RenderViewHost* render_view_host,
if (pending_dom_ui_.get())
render_view_host->AllowBindings(pending_dom_ui_->bindings());
// Tell the RenderView whether it will be used for an extension process.
Profile* profile = delegate_->GetControllerForRenderManager().profile();
- bool is_extension_process = profile->GetExtensionService() &&
- profile->GetExtensionService()->ExtensionBindingsAllowed(entry.url());
- render_view_host->set_is_extension_process(is_extension_process);
+ ExtensionService* service = profile->GetExtensionService();
+ if (service) {
+ bool is_extension_process = service->ExtensionBindingsAllowed(entry.url());
+ render_view_host->set_is_extension_process(is_extension_process);
+ const Extension* installed_app = service->GetInstalledApp(entry.url());
+ render_view_host->set_installed_app(installed_app);
Matt Perry 2011/01/26 20:09:23 I think you'll have to do this for BalloonHost (us
Charlie Reis 2011/03/01 21:33:11 Done.
+ }
return delegate_->CreateRenderViewForRenderManager(render_view_host);
}
@@ -484,11 +484,16 @@ bool RenderViewHostManager::InitRenderView(RenderViewHost* render_view_host,
if (pending_dom_ui_.get())
render_view_host->AllowBindings(pending_dom_ui_->bindings());
- // Tell the RenderView whether it will be used for an extension process.
+ // Tell the RenderView whether it will be used for an extension process or an
+ // installed app.
Profile* profile = delegate_->GetControllerForRenderManager().profile();

Powered by Google App Engine
This is Rietveld 408576698